@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021-2022 Golubchikov Mihail <https://github.com/rue-ryuzaki>
+* Copyright (c) 2021-2023 Golubchikov Mihail <https://github.com/rue-ryuzaki>
 */
 
 #include <argparse/argparse.hpp>
@@ -678,3 +678,53 @@ TEST_CASE("1. to string", "[namespace]")
         REQUIRE_THROWS(parser.parse_args("a a"));
     }
 }
+
+TEST_CASE("2. get", "[namespace]")
+{
+    std::string bar = "bar";
+    std::string foo = "foo";
+
+    SECTION("2.1. first long option containing internal -") {
+        argparse::ArgumentParser parser = argparse::ArgumentParser().exit_on_error(false);
+        parser.add_argument("--foo-bar", "--foo");
+        parser.add_argument(argparse::Argument("--bar-foo", "--bar"));
+
+        argparse::Namespace args = parser.parse_args("--foo=" + foo + " --bar=" + bar);
+
+        REQUIRE(args.get<std::string>("--foo") == foo);
+        REQUIRE(args.get<std::string>("--foo-bar") == foo);
+        REQUIRE(args.get<std::string>("foo") == foo);
+        REQUIRE(args.get<std::string>("foo-bar") == foo);
+        REQUIRE(args.exists("foo_bar") == true);
+        REQUIRE(args.get<std::string>("foo_bar") == foo);
+
+        REQUIRE(args.get<std::string>("--bar") == bar);
+        REQUIRE(args.get<std::string>("--bar-foo") == bar);
+        REQUIRE(args.get<std::string>("bar") == bar);
+        REQUIRE(args.get<std::string>("bar-foo") == bar);
+        REQUIRE(args.exists("bar_foo") == true);
+        REQUIRE(args.get<std::string>("bar_foo") == bar);
+    }
+
+    SECTION("2.2. second long option containing internal -") {
+        argparse::ArgumentParser parser = argparse::ArgumentParser().exit_on_error(false);
+        parser.add_argument("--foo", "--foo-bar");
+        parser.add_argument(argparse::Argument("--bar", "--bar-foo"));
+
+        argparse::Namespace args = parser.parse_args("--foo=" + foo + " --bar=" + bar);
+
+        REQUIRE(args.get<std::string>("--foo") == foo);
+        REQUIRE(args.get<std::string>("--foo-bar") == foo);
+        REQUIRE(args.get<std::string>("foo") == foo);
+        REQUIRE(args.get<std::string>("foo-bar") == foo);
+        REQUIRE(args.exists("foo_bar") == false);
+        REQUIRE_THROWS(args.get<std::string>("foo_bar"));
+
+        REQUIRE(args.get<std::string>("--bar") == bar);
+        REQUIRE(args.get<std::string>("--bar-foo") == bar);
+        REQUIRE(args.get<std::string>("bar") == bar);
+        REQUIRE(args.get<std::string>("bar-foo") == bar);
+        REQUIRE(args.exists("bar_foo") == false);
+        REQUIRE_THROWS(args.get<std::string>("bar_foo"));
+    }
+}
